
#ifndef MYMAINFRAME_H_
#define MYMAINFRAME_H_

#include <TEllipse.h>
#include <TQObject.h>
#include <TASImage.h>
#include <TGFrame.h>
#include <TRootEmbeddedCanvas.h>

class ROI;

//----- The GUI ----------------------------------------------------------------------------
class MyMainFrame : public TGMainFrame {
private:
	TRootEmbeddedCanvas 	*fEmbCanvas;
	TASImage	      		*fImg;
	std::vector<ROI*>		fROIVector;

public:
	MyMainFrame(const TGWindow *p, UInt_t w, UInt_t h);
	virtual ~MyMainFrame(){};

	virtual void CloseWindow();

	virtual void AddROICircle();
	virtual void AddROIEllipse();
	virtual void DeleteROIs();
	virtual void LoadROIs();
	virtual void SaveROIs();

	ClassDef(MyMainFrame, 1)
};


//----- ROI (Region Of Interest) : Abstract base class -------------------------------------
class ROI : public TQObject {
public:
	ROI(){}
	ROI(const ROI &roi){}
	virtual ~ROI(){}

	virtual ROI					*Clone() = 0;
	static ROI					*Create(TClass *roiClass);
	virtual void				Draw() = 0;
	virtual Int_t				Read(const char *name) = 0;
	virtual Int_t				Write(const char *name=0, Int_t option=0, Int_t bufsize=0) = 0;

	ClassDef(ROI, 1);	// An abstract base class for region-of-interests (ROI)
};

//----- ROIEllipse -------------------------------------------------------------------------
class ROIEllipse : public TEllipse, public ROI {
public:
	ROIEllipse(Double_t x1NDC=0.7, Double_t y1NDC=0.7, Double_t r1NDC=0.2, Double_t r2NDC=0.1);
	ROIEllipse(const ROIEllipse &roi);
	virtual ~ROIEllipse(){};

	virtual ROIEllipse			*Clone(){ return new ROIEllipse(*this); }
	virtual void				Draw(){ TEllipse::Draw(); }
	ROIEllipse					&operator=(const ROIEllipse &roiEllipse);
	virtual Int_t				Read(const char *name){ return TObject::Read(name); };
	virtual Int_t				Write(const char *name=0, Int_t option=0, Int_t bufsize=0){ return TObject::Write(name,option,bufsize); };

	ClassDef(ROIEllipse, 1);	// An elliptical region-of-interest
};

//----- ROICircle --------------------------------------------------------------------------
class ROICircle : public ROIEllipse {
public:
	ROICircle(Double_t x1NDC=0.2, Double_t y1NDC=0.5, Double_t r1NDC=0.1) : ROIEllipse(x1NDC,y1NDC,r1NDC,r1NDC) {};
	ROICircle(const ROICircle &roi) : ROIEllipse(roi) {};
	virtual ~ROICircle(){};

	virtual ROICircle			*Clone(){ return new ROICircle(*this); }
	ROICircle					&operator=(const ROICircle &roiCircle);

	ClassDef(ROICircle, 1);	// A circular region-of-interest
};

#endif /* MYMAINFRAME_H_ */
